@@ -20,6 +20,7 @@ extensions = [
     'sphinx.ext.mathjax',
     'sphinx.ext.napoleon',
     'sphinx.ext.viewcode',
+    'sphinx_autodoc_typehints',
     'sphinx_copybutton',
     'nbsphinx',
     'pyg',
@@ -41,33 +42,29 @@ suppress_warnings = ['autodoc.import_object']
 intersphinx_mapping = {
     'python': ('https://docs.python.org/', None),
     # 'numpy': ('http://docs.scipy.org/doc/numpy', None),
-    'pandas': ('http://pandas.pydata.org/pandas-docs/dev', None),
-    'torch': ('https://pytorch.org/docs/master', None),
+    'pandas': ('http://pandas.pydata.org/pandas-docs/stable', None),
+    'torch': ('https://pytorch.org/docs/main', None),
 }
 
+typehints_use_rtype = False
+typehints_defaults = 'comma'
+
 nbsphinx_thumbnails = {
-    'tutorial/create_gnn':
-    '_static/thumbnails/create_gnn.png',
-    'tutorial/heterogeneous':
-    '_static/thumbnails/heterogeneous.png',
-    'tutorial/create_dataset':
-    '_static/thumbnails/create_dataset.png',
-    'tutorial/load_csv':
-    '_static/thumbnails/load_csv.png',
-    'tutorial/neighbor_loader':
-    '_static/thumbnails/neighbor_loader.png',
-    'tutorial/point_cloud':
-    '_static/thumbnails/point_cloud.png',
-    'tutorial/explain':
-    '_static/thumbnails/explain.png',
+    'tutorial/create_gnn': '_static/thumbnails/create_gnn.png',
+    'tutorial/heterogeneous': '_static/thumbnails/heterogeneous.png',
+    'tutorial/create_dataset': '_static/thumbnails/create_dataset.png',
+    'tutorial/load_csv': '_static/thumbnails/load_csv.png',
+    'tutorial/dataset_splitting': '_static/thumbnails/dataset_splitting.png',
+    'tutorial/neighbor_loader': '_static/thumbnails/neighbor_loader.png',
+    'tutorial/point_cloud': '_static/thumbnails/point_cloud.png',
+    'tutorial/explain': '_static/thumbnails/explain.png',
     'tutorial/shallow_node_embeddings':
     '_static/thumbnails/shallow_node_embeddings.png',
-    'tutorial/distributed_pyg':
-    '_static/thumbnails/distributed_pyg.png',
-    'tutorial/multi_gpu_vanilla':
-    '_static/thumbnails/multi_gpu_vanilla.png',
+    'tutorial/distributed_pyg': '_static/thumbnails/distributed_pyg.png',
+    'tutorial/multi_gpu_vanilla': '_static/thumbnails/multi_gpu_vanilla.png',
     'tutorial/multi_node_multi_gpu_vanilla':
     '_static/thumbnails/multi_gpu_vanilla.png',
+    'tutorial/graph_transformer': '_static/thumbnails/graph_transformer.png',
 }
 
 
@@ -78,5 +75,9 @@ def rst_jinja_render(app, _, source):
 
 
 def setup(app):
+    r"""Setup sphinx application."""
     app.connect('source-read', rst_jinja_render)
     app.add_js_file('js/version_alert.js')
+
+    # Do not drop type hints in signatures:
+    del app.events.listeners['autodoc-process-signature']
