@@ -418,6 +418,96 @@ def test_data_update():
     assert torch.equal(data.z, torch.arange(10, 15))
 
 
+def test_data_connected_components():
+    data = Data()
+    data.x = torch.tensor([[1.0], [2.0], [3.0], [4.0], [5.0]])
+    data.y = torch.tensor([[1.1, 1.2], [2.1, 2.2], [3.1, 3.2], [4.1, 4.2],
+                           [5.1, 5.2]])
+    data.edge_index = torch.tensor([[0, 1, 2, 3], [1, 0, 3, 2]],
+                                   dtype=torch.long)
+
+    split_data = data.connected_components()
+    assert isinstance(split_data, list)
+    assert len(split_data) == 3
+
+    assert torch.equal(split_data[0].x, torch.tensor([[1.0], [2.0]]))
+    assert torch.equal(split_data[0].y, torch.tensor([[1.1, 1.2], [2.1, 2.2]]))
+    assert torch.equal(split_data[0].edge_index, torch.tensor([[0, 1], [1,
+                                                                        0]]))
+
+    assert torch.equal(split_data[1].x, torch.tensor([[3.0], [4.0]]))
+    assert torch.equal(split_data[1].y, torch.tensor([[3.1, 3.2], [4.1, 4.2]]))
+    assert torch.equal(split_data[1].edge_index, torch.tensor([[0, 1], [1,
+                                                                        0]]))
+
+    assert torch.equal(split_data[2].x, torch.tensor([[5.0]]))
+    assert torch.equal(split_data[2].y, torch.tensor([[5.1, 5.2]]))
+    assert torch.equal(split_data[2].edge_index,
+                       torch.tensor([[], []], dtype=torch.long))
+
+
+def test_data_find_parent():
+
+    # Case 1: Parent does not exist
+    data = Data()
+    data._parents = {}
+    data._ranks = {}
+    node = 1
+    assert data._find_parent(node) == node
+    assert data._parents == {1: 1}
+    assert data._ranks == {1: 0}
+
+    # Case 2: Parent exists
+    data._parents[node] = 0
+    assert data._find_parent(node) == 0
+
+
+def test_data_union():
+
+    # Setup: two nodes in different sets
+    data = Data()
+    data._parents = {}
+    data._ranks = {}
+    node1 = 1
+    node2 = 2
+
+    # Initially, both nodes are their own parents with rank 0
+    assert data._find_parent(node1) == node1
+    assert data._find_parent(node2) == node2
+    data._ranks[node1] = 0
+    data._ranks[node2] = 0
+
+    # Union them: node2 should now point to node1, and node1's rank increases
+    data._union(node1, node2)
+    assert data._find_parent(node1) == node1
+    assert data._find_parent(node2) == node1
+    assert data._ranks[node1] == 1
+
+    # Add a third node with higher rank and union with node1
+    node3 = 3
+    data._parents[node3] = node3
+    data._ranks[node3] = 2
+    data._union(node1, node3)
+    # node1's parent should now be node3, since node3 has higher rank
+    assert data._find_parent(node1) == node3
+    assert data._find_parent(node3) == node3
+
+    # Add a fourth node with lower rank and union with node3
+    node4 = 4
+    data._parents[node4] = node4
+    data._ranks[node4] = 0
+    data._union(node3, node4)
+    assert data._find_parent(node4) == node3
+    assert data._find_parent(node3) == node3
+
+    # Union of already connected nodes should not change anything
+    prev_ranks = data._ranks.copy()
+    prev_parents = data._parents.copy()
+    data._union(node1, node3)
+    assert data._ranks == prev_ranks
+    assert data._parents == prev_parents
+
+
 # Feature Store ###############################################################
 
 
@@ -582,3 +672,14 @@ def test_data_time_handling(num_nodes, num_edges):
 
     out = out.sort_by_time()
     assert torch.equal(out.time, data.time.repeat_interleave(2))
+
+
+def test_data_inc():
+    data = Data(edge_index=torch.tensor([[0, 1], [1, 0]]))
+    with pytest.warns(UserWarning, match="Unable to accurately infer"):
+        assert data.__inc__('edge_index', data.edge_index) == 2
+
+        data = Data(index=torch.empty(2, 0, dtype=torch.long))
+    with pytest.raises(RuntimeError, match="Unable to infer"):
+        with pytest.warns(UserWarning, match="Unable to accurately infer"):
+            data.__inc__('index', data.edge_index)
