@@ -295,7 +295,7 @@ if __name__ == '__main__':
     for _ in range(2):
         print(f'Start loading {len(loader)} mini-batches ... ', end='')
         t = time.perf_counter()
-        for batch in loader:
+        for _ in loader:
             pass
         print(f'Done! [{time.perf_counter() - t:.4f}s]')
 
@@ -306,7 +306,7 @@ if __name__ == '__main__':
     for _ in range(2):
         print(f'Start loading {len(loader)} mini-batches ... ', end='')
         t = time.perf_counter()
-        for batch in loader:
+        for _ in loader:
             pass
         print(f'Done! [{time.perf_counter() - t:.4f}s]')
 
