@@ -122,12 +122,11 @@ def test_my_conv_basic():
         assert torch.allclose(conv((x1, None), adj2.t()), out2, atol=1e-6)
 
     # Test gradient computation for `torch.sparse` tensors:
-    if torch_geometric.typing.WITH_PT112:
-        conv.fuse = True
-        torch_adj_t = adj1.t().requires_grad_()
-        out = conv((x1, x2), torch_adj_t)
-        out.sum().backward()
-        assert torch_adj_t.grad is not None
+    conv.fuse = True
+    torch_adj_t = adj1.t().requires_grad_()
+    out = conv((x1, x2), torch_adj_t)
+    out.sum().backward()
+    assert torch_adj_t.grad is not None
 
 
 def test_my_conv_save(tmp_path):
@@ -168,7 +167,8 @@ class MyCommentedConv(MessagePassing):
 
 
 def test_my_commented_conv():
-    # Check that `self.propagate` occurences in comments are correctly ignored.
+    # Check that `self.propagate` occurrences in comments are correctly
+    # ignored.
     x = torch.randn(4, 8)
     edge_index = torch.tensor([[0, 1, 2, 3], [0, 0, 1, 1]])
 
