@@ -103,11 +103,7 @@ def test_identical_linear_default_initialization(lazy):
 
 def test_copy_unintialized_parameter():
     weight = UninitializedParameter()
-    if torch_geometric.typing.WITH_PT113:
-        copy.deepcopy(weight)
-    else:  # PyTorch <= 1.12
-        with pytest.raises(Exception):
-            copy.deepcopy(weight)
+    copy.deepcopy(weight)
 
 
 @withDevice
