@@ -1,9 +1,10 @@
 import torch
 
 from torch_geometric.nn import SignedGCN
-from torch_geometric.testing import is_full_test
+from torch_geometric.testing import has_package, is_full_test
 
 
+# @withPackage('sklearn')
 def test_signed_gcn():
     model = SignedGCN(8, 16, num_layers=2, lamb=5)
     assert str(model) == 'SignedGCN(8, 16, num_layers=2)'
@@ -19,8 +20,15 @@ def test_signed_gcn():
     assert train_neg_index.size() == (2, 32)
     assert test_neg_index.size() == (2, 8)
 
-    x = model.create_spectral_features(train_pos_index, train_neg_index, 10)
-    assert x.size() == (10, 8)
+    if has_package('sklearn'):
+        x = model.create_spectral_features(
+            train_pos_index,
+            train_neg_index,
+            num_nodes=10,
+        )
+        assert x.size() == (10, 8)
+    else:
+        x = torch.randn(10, 8)
 
     z = model(x, train_pos_index, train_neg_index)
     assert z.size() == (10, 16)
@@ -28,9 +36,10 @@ def test_signed_gcn():
     loss = model.loss(z, train_pos_index, train_neg_index)
     assert loss.item() >= 0
 
-    auc, f1 = model.test(z, test_pos_index, test_neg_index)
-    assert auc >= 0
-    assert f1 >= 0
+    if has_package('sklearn'):
+        auc, f1 = model.test(z, test_pos_index, test_neg_index)
+        assert auc >= 0
+        assert f1 >= 0
 
     if is_full_test():
         jit = torch.jit.export(model)
