@@ -1,6 +1,5 @@
 import torch
 
-import torch_geometric.typing
 from torch_geometric.nn.pool.connect import FilterEdges
 from torch_geometric.nn.pool.select import SelectOutput
 from torch_geometric.testing import is_full_test
@@ -26,7 +25,7 @@ def test_filter_edges():
     assert out1.edge_attr.tolist() == [3, 5]
     assert out1.batch.tolist() == [0, 1]
 
-    if torch_geometric.typing.WITH_PT113 and is_full_test():
+    if is_full_test():
         jit = torch.jit.script(connect)
         out2 = jit(select_output, edge_index, edge_attr, batch)
         torch.equal(out1.edge_index, out2.edge_index)
