@@ -1,6 +1,5 @@
 import torch
 
-import torch_geometric.typing
 from torch_geometric.nn import (
     GATConv,
     GCNConv,
@@ -40,7 +39,7 @@ def test_sag_pooling():
         assert out3[0].size() == (2, in_channels)
         assert out3[1].size() == (2, 2)
 
-        if torch_geometric.typing.WITH_PT113 and is_full_test():
+        if is_full_test():
             jit1 = torch.jit.script(pool1)
             assert torch.allclose(jit1(x, edge_index)[0], out1[0])
 
