@@ -6,7 +6,7 @@ from torch_geometric.testing import withDevice
 
 @withDevice
 def test_positional_encoding(device):
-    encoder = PositionalEncoding(64).to(device)
+    encoder = PositionalEncoding(64, device=device)
     assert str(encoder) == 'PositionalEncoding(64)'
 
     x = torch.tensor([1.0, 2.0, 3.0], device=device)
@@ -15,7 +15,7 @@ def test_positional_encoding(device):
 
 @withDevice
 def test_temporal_encoding(device):
-    encoder = TemporalEncoding(64).to(device)
+    encoder = TemporalEncoding(64, device=device)
     assert str(encoder) == 'TemporalEncoding(64)'
 
     x = torch.tensor([1.0, 2.0, 3.0], device=device)
