@@ -3,7 +3,7 @@ from unittest.mock import patch
 
 import pytest
 
-from torch_geometric.warnings import warn
+from torch_geometric.warnings import WarningCache, warn
 
 
 def test_warn():
@@ -17,3 +17,19 @@ def test_no_warn_if_compiling(_):
     with warnings.catch_warnings():
         warnings.simplefilter('error')
         warn('test')
+
+
+def test_warning_cache():
+    cache = WarningCache()
+    assert len(cache) == 0
+
+    cache.warn('test')
+    assert len(cache) == 1
+    assert 'test' in cache
+
+    cache.warn('test')
+    assert len(cache) == 1
+
+    cache.warn('test2')
+    assert len(cache) == 2
+    assert 'test2' in cache
