@@ -14,11 +14,10 @@ def test_sort_edge_index():
     out = sort_edge_index(edge_index)
     assert out.tolist() == [[0, 1, 1, 2], [1, 0, 2, 1]]
 
-    if torch_geometric.typing.WITH_PT113:
-        torch_geometric.typing.MAX_INT64 = 1
-        out = sort_edge_index(edge_index)
-        torch_geometric.typing.MAX_INT64 = torch.iinfo(torch.int64).max
-        assert out.tolist() == [[0, 1, 1, 2], [1, 0, 2, 1]]
+    torch_geometric.typing.MAX_INT64 = 1
+    out = sort_edge_index(edge_index)
+    torch_geometric.typing.MAX_INT64 = torch.iinfo(torch.int64).max
+    assert out.tolist() == [[0, 1, 1, 2], [1, 0, 2, 1]]
 
     out = sort_edge_index((edge_index[0], edge_index[1]))
     assert isinstance(out, tuple)
