@@ -125,8 +125,8 @@ class Batch(metaclass=DynamicInheritance):
             cls=self.__class__.__bases__[-1],
             batch=self,
             idx=idx,
-            slice_dict=getattr(self, '_slice_dict'),
-            inc_dict=getattr(self, '_inc_dict'),
+            slice_dict=self._slice_dict,
+            inc_dict=self._inc_dict,
             decrement=True,
         )
 
