@@ -12,6 +12,7 @@ from .re_net import RENet
 from .graph_unet import GraphUNet
 from .schnet import SchNet
 from .dimenet import DimeNet, DimeNetPlusPlus
+from .gpse import GPSE, GPSENodeEncoder
 from .captum import to_captum_model
 from .metapath2vec import MetaPath2Vec
 from .deepgcn import DeepGCNLayer
@@ -28,11 +29,14 @@ from .gnnff import GNNFF
 from .pmlp import PMLP
 from .neural_fingerprint import NeuralFingerprint
 from .visnet import ViSNet
-from .g_retriever import GRetriever
+from .lpformer import LPFormer
+from .sgformer import SGFormer
 
+from .polynormer import Polynormer
 # Deprecated:
 from torch_geometric.explain.algorithm.captum import (to_captum_input,
                                                       captum_output_to_dicts)
+from .attract_repel import ARLinkPredictor
 
 __all__ = classes = [
     'MLP',
@@ -58,6 +62,8 @@ __all__ = classes = [
     'SchNet',
     'DimeNet',
     'DimeNetPlusPlus',
+    'GPSE',
+    'GPSENodeEncoder',
     'to_captum_model',
     'to_captum_input',
     'captum_output_to_dicts',
@@ -76,5 +82,8 @@ __all__ = classes = [
     'PMLP',
     'NeuralFingerprint',
     'ViSNet',
-    'GRetriever',
+    'LPFormer',
+    'SGFormer',
+    'Polynormer',
+    'ARLinkPredictor',
 ]
