@@ -64,7 +64,7 @@ class GraphUNet(torch.nn.Module):
         in_channels = channels if sum_res else 2 * channels
 
         self.up_convs = torch.nn.ModuleList()
-        for i in range(depth - 1):
+        for _ in range(depth - 1):
             self.up_convs.append(GCNConv(in_channels, channels, improved=True))
         self.up_convs.append(GCNConv(in_channels, out_channels, improved=True))
 
@@ -79,12 +79,21 @@ class GraphUNet(torch.nn.Module):
         for conv in self.up_convs:
             conv.reset_parameters()
 
-    def forward(self, x: Tensor, edge_index: Tensor,
-                batch: OptTensor = None) -> Tensor:
+    def forward(
+        self,
+        x: Tensor,
+        edge_index: Tensor,
+        batch: OptTensor = None,
+        edge_weight: Tensor = None,
+    ) -> Tensor:
         """"""  # noqa: D419
         if batch is None:
             batch = edge_index.new_zeros(x.size(0))
-        edge_weight = x.new_ones(edge_index.size(1))
+
+        if edge_weight is None:
+            edge_weight = x.new_ones(edge_index.size(1))
+        assert edge_weight.dim() == 1
+        assert edge_weight.size(0) == edge_index.size(1)
 
         x = self.down_convs[0](x, edge_index, edge_weight)
         x = self.act(x)
