@@ -17,11 +17,13 @@ from .decorators import (
     onlyOnline,
     onlyGraphviz,
     onlyNeighborSampler,
+    onlyRAG,
     has_package,
     withPackage,
     withDevice,
     withCUDA,
     withMETIS,
+    withHashTensor,
     disableExtensions,
     withoutExtensions,
 )
@@ -48,11 +50,13 @@ __all__ = [
     'onlyOnline',
     'onlyGraphviz',
     'onlyNeighborSampler',
+    'onlyRAG',
     'has_package',
     'withPackage',
     'withDevice',
     'withCUDA',
     'withMETIS',
+    'withHashTensor',
     'disableExtensions',
     'withoutExtensions',
     'assert_module',
