@@ -245,7 +245,7 @@ class RandomLinkSplit(BaseTransform):
                 warnings.warn(
                     f"There are not enough negative edges to satisfy "
                     "the provided sampling ratio. The ratio will be "
-                    f"adjusted to {ratio:.2f}.")
+                    f"adjusted to {ratio:.2f}.", stacklevel=2)
                 num_neg_train = int((num_neg_train / num_neg) * num_neg_found)
                 num_neg_val = int((num_neg_val / num_neg) * num_neg_found)
                 num_neg_test = num_neg_found - num_neg_train - num_neg_val
