@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Optional, Union
 
 from torch_geometric.data import Data, HeteroData
 from torch_geometric.data.datapipes import functional_transform
@@ -22,9 +22,11 @@ class RemoveDuplicatedEdges(BaseTransform):
     """
     def __init__(
         self,
-        key: Union[str, List[str]] = ['edge_attr', 'edge_weight'],
+        key: Optional[Union[str, List[str]]] = None,
         reduce: str = "add",
     ) -> None:
+        key = key or ['edge_attr', 'edge_weight']
+
         if isinstance(key, str):
             key = [key]
 
